#!/usr/bin/env ruby1.8
=begin
/*
 * Copyright 2011, 2012 Canonical Ltd.
 *
 * Original author:
 * - Gerry Boland <gerry.boland@canonical.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
=end

# Testability test suite execution script
# 
# Run all tests with
#   $ ruby run-tests.rb

# Check script being run by Ruby 1.8.x, later versions not supported by TDriver
abort("Aborted! Ruby 1.9 not supported, use 1.8") unless RUBY_VERSION < '1.9'

# Time verify_* assertions should wait until they throw exception 
TIMEOUT = 10

# Add ./misc/lib to the list of library locations - need to calculate absolute path
require 'pathname'
$library_path = File.expand_path(File.dirname(__FILE__)) + '/misc/lib'
$actions_path = File.expand_path(File.dirname(__FILE__)) + '/shared/actions'
$LOAD_PATH.unshift $library_path

# The following line includes the complete tdriver environment 
require 'tdriver'
include TDriverVerify

# Require unit test framework: This enables execution of test cases and also includes assertions (Test::Unit::Assertions)
require 'testhelper'

# Establish connection to qttasserver
$SUT = TDriver.sut(:Id => "sut_qt")

# Enable reports only with -report switch
include TDriverReportTestUnit if ARGV.delete('-report')

# List of directories in which to search for test cases
test_directories = ['controlpanel']

# Only run scan for tests if this script is directly called
if __FILE__ == $0
    $INIT_COMPLETED = true # Prevent this file being included by test cases

     # Scan through the above directories and execute test cases contained.
    test_directories.each do | directory |
         Dir["#{directory}/*.rb"].each { |testCase| require testCase }
    end
end
