# -*- coding: utf-8 -*-

# Authors: 
#     Leo Arias <leo.arias@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Test case u1webf-001 Upload File.
Upload a file to Ubuntu One storage service, through the website.

"""

from sst.actions import *
import actions.setup as setup_actions
import actions.files as files_actions
from os import path, remove
import tempfile
import uuid

setup_actions.setup()
files_actions.open()
file_uuid = str(uuid.uuid1())
file_contents = 'This is test file %s' % file_uuid
file_name = None
with tempfile.NamedTemporaryFile(mode='wr', prefix='New file ',
                                 suffix=file_uuid + '.txt',
                                 delete=False) as upload:
    upload.write(file_contents)
    upload.close()
    files_actions.upload_file(upload.name)
    file_name = path.basename(upload.name)
    remove(upload.name)
files_actions.assert_file_exists(file_name)
assert files_actions.get_file_upload_date(file_name) == 'Just now'
assert files_actions.get_file_size(file_name) == '54 bytes'
files_actions.assert_file_information_is_shown(file_name)
files_actions.assert_file_type(file_name, 'text/plain')
