# -*- coding: utf-8 -*-

# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.


import os
import uuid

from sst.actions import *
import actions.setup as setup_actions
import actions.files as files_actions
import actions.photos as photos_actions
from utils.randomphotos import make_random_photo_and_return_path 


setup_actions.setup(new_user=False)

# generate temporary images
random_photo_path1 = make_random_photo_and_return_path()
random_photo_path2 = make_random_photo_and_return_path()
photo_name1 = os.path.basename(random_photo_path1)
photo_name2 = os.path.basename(random_photo_path2)

# create a new folder
files_actions.open()
folder_uuid = str(uuid.uuid1())
folder_name = 'Folder to order photos %s' % folder_uuid
files_actions.create_new_folder(folder_name)
files_actions.open_folder(folder_name)

# upload photos and remove local versions
photo_paths = (random_photo_path1, random_photo_path2)
for photo_path in photo_paths:
    files_actions.upload_file(photo_path)
    os.remove(photo_path)

# XXX refresh because there is a bug in edge server.
# See https://bugs.launchpad.net/ubuntuone-servers/+bug/1007147
refresh()

# open photos tab and test/assert sorting
photos_actions.open()
photo_names = (photo_name1, photo_name2)
photos_actions.assert_photo_order_in_gallery(reversed(photo_names))
photos_actions.sort_photo_order_oldest_first()
photos_actions.assert_photo_order_in_gallery(photo_names)
photos_actions.sort_photo_order_newest_first()
photos_actions.assert_photo_order_in_gallery(reversed(photo_names))
