# -*- coding: utf-8 -*-

# Copyright 2011, 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Actions for the Dashboard page of the Ubuntu One website."""

from sst.actions import *

PAGE_TITLE = u'Ubuntu One : Dashboard'

def open():
    click_link(_get_dashboard_link())
    assert_page_title(), 'Dashboard should be opened'


def click_files_tab():
    click_link(_get_files_tab_link())


def _get_files_tab_link():
    return get_element_by_css('#main-nav .files')


def _get_dashboard_link():
    return get_element_by_css('#main-nav .dashboard')


def assert_page_title():
    assert_title(PAGE_TITLE)


def wait_for_page_to_load():
    wait_for(assert_title, PAGE_TITLE)


def assert_welcome_message(user_full_name):
    assert_text(_get_welcome_element(), 
        'Hi %s! Welcome Back' % user_full_name[:40])

    
def _get_welcome_element():
    return get_element_by_css('h1')


def assert_number_of_bytes(expected):
    # FIXME: http://pad.lv/1037544 will provide a more robust solution
    nb_bytes = get_element_by_css('a[href="/files/"] .amount')
    assert_text(nb_bytes, expected)


def assert_number_of_contacts(expected):
    # FIXME: http://pad.lv/1037544 will provide a more robust solution
    nb_contacts = get_element_by_css('a[href="/contacts/"] .amount')
    assert_text(nb_contacts, expected)
