# -*- coding: utf-8 -*-

# Authors: 
#     Leo Arias <leo.arias@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Actions for the Payment Confirmed page of the Ubuntu One website."""

from sst.actions import *
from datetime import datetime
from utils import paymentperiods

def assert_page_title():
    """Assert that the title of the page is the expected."""
    assert_title(u'Ubuntu One : Confirm Payment Details')

def assert_failed_payment():
    """Assert that the payment failed."""
    get_element(tag='h1', text='Your Payment Failed')
    get_element(tag='a', text='fill out the details here', 
                href='/services/checkout/')

def assert_processed_payment(period, paid, price, trial=False):
    """Assert that the payment was processed.

    Keyword arguments:
    period -- The period of the service paid.
    paid -- The paid amount.
    price -- The price of the service, per period.
    trial -- Indicates if the service paid has a trial period
             (default False).

    """
    get_element(tag='h1', text='Payment Processed')
    today = datetime.utcnow()
    if trial:
        expire_date = paymentperiods.get_trial_expiration_date()
    elif period == 'monthly':
        expire_date = paymentperiods.get_monthly_expiration_date()
    elif period == 'annually':
        expire_date = paymentperiods.get_yearly_expiration_date()
    # TODO assert the paid amount.
    # TODO assert payments in euros.
    element_expire_date = _get_purchase_details_data_elements()[0]
    assert_text(element_expire_date, expire_date.strftime('%B %-d, %Y'))
    get_element(tag='p', css_class='explanation',
                text='Your card will automatically be billed $%(price)s ' \
                     '%(period)s' % {'price': str(price), 'period': period})
    element_payment_status = _get_purchase_details_data_elements()[1]
    assert_text(element_payment_status, 'AUTHORISED')

def _get_purchase_details_data_elements():
    return get_elements_by_css('dl.purchase_details > dd')

def view_account():
    """Go to the account information page."""
    click_link(get_element(tag='a', text='View your account'))
