# -*- coding: utf-8 -*-

# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Actions for the Photos page of the Ubuntu One website."""

from sst.actions import *
from loading import *



def open():
    click_photos_tab()
    switch_to_window()


def click_photos_tab():
    click_link(_get_photos_tab_link())


def _get_photos_tab_link():
    return get_element_by_css('#main-nav .photos')


def assert_page_title():
    assert_title(u'Ubuntu One : Photos')


def _assert_page_heading1(folder_name):
    heading1_element = get_element(tag='h1')
    assert_text(heading1_element, folder_name)


# List view actions.
# TODO make sure we are viewing the photo list.

def assert_photo_is_present_in_list(photo_name):
    photo_link = _get_photo_link_in_list(photo_name)
    assert_displayed(photo_element)


def _get_photo_link_in_list(photo_name):
    return get_element('.photo-list a[data-u1name="%(name)s"]'
        % {'name': photo_name})


def _get_photo_links_in_list():
    return get_elements('.photo-list a[data-u1name]')


def get_photo_id(photo_name):
    photo_link = _get_photo_link_in_list(photo_name)
    return photo_link.get_attribute('data-u1nodekey')


def open_photo(photo_name):
    photo_element = _get_photo_element_in_list(photo_name)
    click_element(photo_element)
    # XXX find a better way to wait for the gallery to load.
    sleep(10)


def _get_photo_element_in_list(photo_name):
   photo_link = _get_photo_link_in_list(photo_name)
   return photo_link.find_element_by_css_selector('img')


def _get_photo_elements_in_list():
   elems = []
   for photo_link in _get_photo_links_in_list():
       elem = photo_link.find_element_by_css_selector('img')
       elems.append(elem)
   return elems


# Gallery view actions.
# TODO make sure we are viewing the photo gallery.

def assert_photo_name_in_gallery(photo_name):
    heading1_element = get_element_by_css('.title h1')
    assert_text(heading1_element, photo_name)


def assert_photo_is_present_in_gallery(photo_id):
    photo_element = _get_photo_element_in_gallery(photo_id)
    assert_displayed(photo_element)


def _get_photo_names_from_gallery():
    elems = _get_photo_elements_in_list()
    photo_names = [str(elem.get_attribute('data-qa-id')) for elem in elems]
    return photo_names


def assert_photo_order_in_gallery(photo_names):
    names = _get_photo_names_from_gallery()
    assert_equal(names, list(photo_names))


def sort_photo_order_newest_first():
    set_dropdown_value('photo-order', 'Show newest photos first')


def sort_photo_order_oldest_first():
    set_dropdown_value('photo-order', 'Show oldest photos first')


def _get_photo_element_in_gallery(photo_id):
    photo_css_locator = _get_photo_element_css_locator_in_gallery(photo_id)
    return get_element_by_css(photo_css_locator)


def _get_photo_element_css_locator_in_gallery(photo_id):
    # TODO take into account staging url.
    photo_source_url_format = 'https://files.one.ubuntu.com/thumbnail/file_storage/{0}/1000x1000'
    photo_source_url = photo_source_url_format.format(photo_id)
    return '.photoset .photo > img[src="{0}"]'.format(photo_source_url)


def assert_photo_is_present_in_gallery_sidebar(photo_id):
    photo_element = _get_photo_element_in_gallery_sidebar(photo_id)
    assert_displayed(photo_element)


def _get_photo_element_in_gallery_sidebar(photo_id):
    photo_css_locator = _get_photo_element_css_locator_in_gallery_sidebar(photo_id)
    return get_element_by_css(photo_css_locator)


def _get_photo_element_css_locator_in_gallery_sidebar(photo_id):
    # TODO take into account staging url.
    photo_source_url_format = 'https://files.one.ubuntu.com/thumbnail/file_storage/{0}/108x108/'
    photo_source_url = photo_source_url_format.format(photo_id)
    return '.photoset .sidebar img[src="{0}"]'.format(photo_source_url)
