# -*- coding: utf-8 -*-

# Copyright 2011, 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Actions for the Services page of the Ubuntu One website."""

from sst.actions import *

def open():
    """Open the services page and assert it's title."""
    go_to('/services/')
    assert_page_title()


def click_services_main_menu_link():
    click_link(_get_services_main_menu_link())


def _get_services_main_menu_link():
    return get_element_by_css('nav[id="main-nav"] .services')


def assert_page_title():
    assert_title(u'Ubuntu One : Services')


def assert_page_heading1():
    heading1_element = get_element(tag='h1')
    assert_text(heading1_element, 'Ubuntu One')    


def agree_and_subscribe_to_free_plan():
    click_button(get_element(name='subscribe'))


def assert_services_information():
    """Assert that the information about the services is the expected."""
    assert_free_service_information()
    assert_music_streaming_service_information()
    assert_storage_service_information()
    assert_discount_information()


def assert_free_service_information():
    """Assert that the information about the free service is the expected."""
    get_element(tag='h2', text='Free')
    get_element(tag='li', text='File sync across platforms')
    get_element(tag='li', text='Share folders and files')
    get_element(tag='li', text='Access on your mobile')


def assert_music_streaming_service_information():
    """Assert that the information about the music streaming service is 
    the expected.

    """
    _assert_music_streaming_heading_text()
    get_element(css_class='six-free', text='6 months FREE')
    get_element(tag='li', text='Music streaming on your mobile')
    get_element(tag='li', text='20GB of Storage for all your data')
    get_element(tag='li', text='Listen offline')
    get_element(tag='li', text='$3.99 / month or $39.99 / year')


def _assert_music_streaming_heading_text():
    music_streaming_heading = get_element_by_css('section.music-streaming > h2')
    assert_text(music_streaming_heading, 'Music Streaming')


def assert_storage_service_information():
    """Assert that the information about the storage service is the 
    expected.

    """
    get_element(tag='h2', text='Storage')
    get_element(tag='li', text='20GB')
    get_element(tag='li', text='$2.99 / month')
    get_element(tag='li', text='$29.99 / year')


def assert_discount_information():
    """Assert that the yearly discount information is the expected."""
    get_element(tag='h2', text='Discount')
    get_element(tag='p', text='Two months free on Music Streaming and Storage '
                              'when you sign up for 12 months')


def buy_music_streaming_monthly():
    """Buy the monthly music streaming service."""
    _click_add_music_streaming()
    _select_music_streaming_monthly()
    _click_next_checkout_button()


def _click_add_music_streaming():
    add_music_streaming_link = get_element(text='Add Music Streaming')
    click_link(add_music_streaming_link)


def _select_music_streaming_monthly():
    set_radio_value('ms1')


def _click_next_checkout_button():
    next_checkout_button = get_element(text='Next-checkout')
    click_button(next_checkout_button)


def buy_music_streaming_yearly():
    """Buy the yearly music streaming service."""
    _click_add_music_streaming()
    _select_music_streaming_yearly()
    _click_next_checkout_button()


def _select_music_streaming_yearly():
    set_radio_value('ms2')


def buy_extra_storage_monthly(quantity):
    """Buy the monthly extra storage service."""
    click_add_extra_storage()
    set_storage_quantity(quantity)
    _select_extra_storage_montly()
    _click_next_checkout_button()


def click_add_extra_storage():
    add_extra_storage_link = get_element(text='Add Extra Storage')
    click_link(add_extra_storage_link)


def set_storage_quantity(quantity):
    """Set the storage quantity to buy.
    
    Keyword arguments: 
    quantity -- The quantity to buy.   

    """
    write_textfield('qty', str(quantity))


def _select_extra_storage_montly():
    set_radio_value('st1')


def buy_extra_storage_yearly(quantity):
    """Buy the yearly extra storage service."""
    click_add_extra_storage()
    set_storage_quantity(quantity)
    _select_extra_storage_yearly()
    _click_next_checkout_button()


def _select_extra_storage_yearly():
    set_radio_value('st2')


def assert_storage(quantity):
    """Asert the storage quantity selected and its space and price. 
    
    Keyword arguments:
    quantity -- The expected storage quantity.

    """
    assert_text('qty', str(quantity))
    assert_text('total-storage', '%sGB' % (quantity * 20 + 5))
    monthly_price = quantity * 2.99
    assert_text('storage-monthly-price', '$%s' % monthly_price)
    annual_price = quantity * 29.99
    assert_text('storage-annual-price', '$%s' % annual_price)


def increase_storage_quantity():
    """Click the button that increases the storage quantity to buy."""
    # -/+ buttons missing on both edge and staging, told beuno
    # https://code.launchpad.net/~stephen-stewart/ubuntuone-servers/one-services-strict-error/+merge/133299
    click_button('plus_qty')


def decrease_storage_quantity():
    """Click the button that decreases the storage quantity to buy."""
    click_button('minus_qty')


def assert_sign_up_now_link_is_present():
    sign_up_link = _get_sign_up_now_link()
    assert_displayed(sign_up_link)


def _get_sign_up_now_link():
    return get_element_by_xpath('//a[contains(text(), "Sign up now")]')
