# -*- coding: utf-8 -*-

# Copyright 2011, 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Single Sign On actions for Ubuntu One."""

from sst.actions import *
from actions.setup import get_base_url

def login(user):
    """Log in to Ubuntu One website.

    Keyword arguments:
    email -- The email of the user.
    password -- The password of the user.

    """
    wait_for(assert_title, 'Log in')
    switch_to_window()
    assert_textfield('id_email')
    assert_textfield('id_password')
    write_textfield('id_email', user.email)
    write_textfield('id_password', user.password)
    click_button(get_element(css_class='btn', name='continue'), wait=False)


def create_new_account(user):
    click_link(get_element(href='+new_account'))
    wait_for(assert_title, 'Create account')
    write_textfield('id_displayname', user.full_name)
    write_textfield('id_email', user.email)
    write_textfield('id_password', user.password)
    write_textfield('id_passwordconfirm', user.password)
    click_button(get_element(name='continue'))


def confirm_email(confirmation_code):
    write_textfield(get_element(name='confirmation_code'), confirmation_code)
    click_button(get_element(css_class='btn', text='Continue'))


def assert_logout():
    assert_title('You have been logged out')
    assert_text(get_element(tag='h1', css_class='main'),
            'You have been logged out')


def return_to_site():
    click_link(get_element_by_css('.returnto a'))
