# -*- coding: utf-8 -*-

# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Data classes for a Contact."""

class Contact:
    "Class for Contact information."

    def __init__(self, name=None, emails=(), phones=(), addresses=(), 
                 instant_messaging_addresses=(), urls=(), role=None, 
                 about_information=None):
        """Class constructor.

        Keyword arguments:
        name -- The name of the contact. Default is None.
        emails -- A sequence with the emails of the contact. Default is an 
            empty tuple.
        phones -- A sequence with the phones of the contact. Default is an 
            empty tuple.
        addresses -- A sequence with the addresses of the contac. Default is 
            an empty tuple.
        instant_messaging_addresses -- A sequence with the instant messaging
            addresses of the contact.  Default is an empty tuple.
        urls -- A sequence with the URLs of the contact.  Default is an empty 
            tuple.
        role -- The job role of the contact. Default is None.
        about_information -- Additional information of the contact. Default is
           None.

        """
        self.name = name
        self.emails = emails
        self.phones = phones
        self.addresses = addresses
        self.instant_messaging_addresses = instant_messaging_addresses
        self.urls = urls
        self.role = role
        self.about_information = about_information
        
class Name:
    """Class for the name of a contact."""

    def __init__(self, title=None, first_name=None, middle_name=None, 
                 last_name=None, suffix=None):
        """Class constructor.

        Keyword arguments:
        title -- The title of the contact. Default is None.
        first_name -- The first name of the contact. Default is None.
        middle_name -- The middle name of the contact. Default is None.
        last_name -- The last name of the contact. Default is None.
        suffix -- The suffix of the contact. Default is None.

        """
        self.title = title
        self.first_name = first_name
        self.middle_name = middle_name
        self.last_name = last_name
        self.suffix = suffix

class Email:
    """Class for the email of a contact."""

    def __init__(self, description, address):
        """Class constructor.
    
        Keyword arguments:
        description -- The description of the email. It can be 'Other',
            'Home' or Work.
        address -- The email address.

        """
        self.description = description
        self.address = address

class Phone:
    """Class for the phone of a contact."""

    def __init__(self, description, number):
        """Class constructor.

        Keyword arguments:
        description -- The description of the phone. It can be 'Home', 
            'Mobile', 'Home fax', 'Work', 'Car', 'Pager', 'Work fax', 
            'Assitant', 'Call back', 'Company', 'Other fax', 'Primary', 
            'Telex' or 'Other'.
        number -- The phone number.

        """
        self.description = description
        self.number = number

class Address:
    """Class for the address of a contact."""

    def __init__(self, description, address1=None, address2=None, po_box=None,
                 city=None, state=None, postal_code=None, country=None):
        """Class constructor.

        Keyword arguments:
        description -- The description of the address. It can be 'Home', 
            'Work' or 'Other'.
        address1 -- The first line of the address. Default is None.
        address2 -- The second line of the address. Default is None.
        po_box -- The post office box number. Default is None.
        city -- The name of the city. Default is None.
        state -- The name of the state. Default is None.
        postal_code -- The postal code number. Default is None.
        country -- The name of the country. Default is None.

        """
        self.description = description
        self.address1 = address1
        self.address2 = address2
        self.po_box = po_box
        self.city = city
        self.state = state
        self.postal_code = postal_code
        self.country = country

class InstantMessagingAddress:
    """Class for the Instant Messaging address of a contact."""

    def  __init__(self, description, address):
        """Class constructor.

        Keyword arguments:
        description -- The description of the instan messaging address. It can
            be 'AIM', 'Gadu-Gadu', 'GroupWise', 'ICQ', 'IRC', 'Jabber', 'MSN', 
            'Skype', 'Yahoo', or 'Other'.
        address -- The instant messaging address.

        """
        self.description = description
        self.address = address

class Url:
    """Class for the Universal Resource Locators of a contact."""
    
    def __init__(self, description, url):
        """Class constructor.

        Keyword arguments:
        description -- The description of the URL.
        url -- The Universal Resource Locator.
        
        """
        self.description = description
        self.url = url

class Role:
    """Class for the role of a contact."""

    def __init__(self, company=None, department=None, job_title=None, 
                 manager_name=None, assistant_name=None):
        """Class constructor.

        Keyword arguments:
        company -- The name of the company. Default is None.
        department -- The name of the department. Default is None.
        job_title -- The name of the job possition. Default is None.
        manager_name -- The name of the manager. Default is None.
        assitant_name -- The name of the assistant. Default is None.

        """
        self.company = company
        self.department = department
        self.job_title = job_title
        self.manager_name = manager_name
        self.assitant_name = assitant_name
    
class AboutInformation:
    """Class for additional information about the contact."""
    
    def __init__(self, nickname=None, birth_date=None, spouse_name=None, 
                 wedding_date=None, notes=None):
        """Class constructor.

        Keyword arguments:
        nickname -- The nickname. Default is None.
        birth_date -- The date of birth. Default is None.
        spouse_name -- The name of the spouse. Default is None.
        wedding_date -- The date of the wedding. Default is None.
        notes -- Additional notes about the contact. Default is None.

        """
        self.nickname = nickname
        self.birth_date = birth_date
        self.spouse_name = spouse_name
        self.wedding_date = wedding_date
        self.notes = notes
